@@ -247,9 +247,9 @@ class Client(Singleton):
         else:
             return False, '未受支持的Backend'
 
-    async def get_from_cloud_async(self, path, url, force_copy=False, min_size=0):
+    async def get_from_cloud_async(self, path, url, force_copy=False, min_size=0, refresh=False):
         file_path = self.index_cache.get(url)
-        if file_path is not None and os.path.isfile(file_path) and os.path.getsize(file_path) // 1024 >= min_size:
+        if file_path is not None and os.path.isfile(file_path) and os.path.getsize(file_path) // 1024 >= min_size and not refresh:
             print('loading from disk...')
             if force_copy:
                 if file_path == path:
@@ -444,7 +444,7 @@ class Client(Singleton):
                         resp = json.loads(resp)
                         if resp['ret']:
                             tmp_url = resp['url']
-                            return await self.get_from_cloud_async(path, tmp_url, force_copy, min_size)
+                            return await self.get_from_cloud_async(path, tmp_url, force_copy, min_size, refresh=True)
                     
                     await asyncio.sleep(1/30)
                 return False, '超时'
